changeset 45184:fe852d8d5495

(make-flyspell-overlay): Add help text to flyspell overlays.
author Pavel Janík <Pavel@Janik.cz>
date Wed, 08 May 2002 15:26:47 +0000
parents c96380f599f5
children f687ce0088e4
files lisp/textmodes/flyspell.el
diffstat 1 files changed, 3 insertions(+), 2 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/textmodes/flyspell.el	Wed May 08 14:42:10 2002 +0000
+++ b/lisp/textmodes/flyspell.el	Wed May 08 15:26:47 2002 +0000
@@ -550,9 +550,9 @@
   ;; otherwise it could be too late, the local dictionary may
   ;; be forgotten!
   (flyspell-accept-buffer-local-defs)
   ;; we put the `flyspel-delayed' property on some commands
   (flyspell-delay-commands)
   ;; we put the `flyspel-deplacement' property on some commands
   (flyspell-deplacement-commands)
   ;; we bound flyspell action to post-command hook
   (add-hook 'post-command-hook (function flyspell-post-command-hook) t t)
@@ -1495,6 +1495,7 @@
     (overlay-put flyspell-overlay 'mouse-face mouse-face)
     (overlay-put flyspell-overlay 'flyspell-overlay t)
     (overlay-put flyspell-overlay 'evaporate t)
+    (overlay-put flyspell-overlay 'help-echo "mouse-2: correct word at point")
     (if flyspell-use-local-map
         (overlay-put flyspell-overlay
                      flyspell-overlay-keymap-property-name
@@ -550,9 +550,9 @@
   ;; be forgotten!
   (flyspell-accept-buffer-local-defs)
-  ;; we put the `flyspel-delayed' property on some commands
+  ;; we put the `flyspell-delayed' property on some commands
   (flyspell-delay-commands)
@@ -550,9 +550,9 @@
   (flyspell-delay-commands)
-  ;; we put the `flyspel-deplacement' property on some commands
+  ;; we put the `flyspell-deplacement' property on some commands
   (flyspell-deplacement-commands)
   ;; we bound flyspell action to post-command hook